#!/bin/bash

# please set your endpoint url (except '/client/api')
# ex. "https://portal2-east.cloud-platform.kddi.ne.jp:10443"
address=""

# please set your api key
api_key=""

# please set your secret key
secret_key=""

# debug=true
# export LC_ALL='C'

# check command, output usage
if [ $# -lt 1 ]; then
    echo "usage: $0 command=... parameter=... parameter=..."; exit;
elif [[ $1 != "command="* ]]; then
    echo "usage: $0 command=... parameter=... parameter=..."; exit;
elif [ $1 == "command=" ]; then
    echo "usage: $0 command=... parameter=... parameter=..."; exit;
fi

# if include '%' in parameter, exit with error.
for par in "$@"
do
    if [ `echo $par |grep '%'` ]
    then
	echo "Invalied Parameter"
	exit 1
    fi
done

command="${1##*command=}"
c=$(echo $command | tr "A-Z" "a-z")
api_path="/client/api?"

# check response format for pretty print
for par in "$@"
do
    p="${par##*response=}"
    p=$(echo $p | tr "A-Z" "a-z")
    if [ "$p" == "json" ]
    then
	json=true
	break
    fi
done



# start making signature
##
[ -n "$debug" ] && echo " debug 1 $@"

data_array=("$@" "apikey=${api_key}")
##
[ -n "$debug" ] && echo " debug 2 ${data_array[@]}"

temp1=$(echo -n ${data_array[@]} | \
	       tr " " "\n" | \
	       sort -fd -t'=' | \
	       perl -pe's/([^-_.\[\]~A-Za-z0-9=\s])/sprintf("%%%02X", ord($1))/seg'| \
	       tr "A-Z" "a-z" | \
	       tr "\n" "&" )
##
[ "$debug" ] && echo " debug 3 sorted ${temp1[@]}"

signature=$(echo -n ${temp1[@]})
signature=${signature%&}
##
[ -n "$debug" ] && echo " debug 4 $signature"

signature=$(echo -n $signature | \
		   openssl sha1 -binary -hmac $secret_key | \
		   openssl base64 )

##
[ -n "$debug" ] && echo " debug 5 signature=$signature"

signature=$(echo -n $signature | \
		   perl -pe's/([^-_.~A-Za-z0-9])/sprintf("%%%02X", ord($1))/seg')
# [ -n "$debug" ] &&  echo " debug 6 urlencoded signature=$signature"


url=${address}${api_path}$(echo -n $@ | sed s/'+'/'%2B'/g | tr " " "&")"&"apikey=$api_key"&"signature=$signature
[ -n "$debug" ] && echo " SEND URL: $url"


if [[ -n $json ]]
then
    curl --globoff ${url} | python -mjson.tool
else
    curl --globoff ${url} | xmllint --format -
fi

# [ -n "$debug" ] && curl -i --globoff ${url}
